==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/StateMachineStateSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.statemachine.StateSet;
import io.ciera.tool.sql.architecture.statemachine.impl.StateSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.I_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineState;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NoEventTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateEventMatrixEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.List;


public class StateMachineStateSetImpl extends InstanceSet<StateMachineStateSet,StateMachineState> implements StateMachineStateSet {

    // attributes
    @Override
    public void setFinal( int m_Final ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setFinal( m_Final );
    }
    @Override
    public void setSMstt_ID( UniqueId m_SMstt_ID ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setSMstt_ID( m_SMstt_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setName( m_Name );
    }
    @Override
    public void setNumb( int m_Numb ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setNumb( m_Numb );
    }


    // selections
    @Override
    public I_INSSet R2915_defines_state_of_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( StateMachineState statemachinestate : this ) i_insset.addAll( statemachinestate.R2915_defines_state_of_I_INS() );
        return i_insset;
    }
    @Override
    public StateSet R4758_State() throws XtumlException {
        StateSet stateset = new StateSetImpl();
        for ( StateMachineState statemachinestate : this ) stateset.add( statemachinestate.R4758_State() );
        return stateset;
    }
    @Override
    public SM_SMSet R501_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( StateMachineState statemachinestate : this ) sm_smset.add( statemachinestate.R501_SM_SM() );
        return sm_smset;
    }
    @Override
    public StateEventMatrixEntrySet R503_receives_StateEventMatrixEntry() throws XtumlException {
        StateEventMatrixEntrySet stateeventmatrixentryset = new StateEventMatrixEntrySetImpl();
        for ( StateMachineState statemachinestate : this ) stateeventmatrixentryset.addAll( statemachinestate.R503_receives_StateEventMatrixEntry() );
        return stateeventmatrixentryset;
    }
    @Override
    public TransitionSet R506_is_destination_of_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( StateMachineState statemachinestate : this ) transitionset.addAll( statemachinestate.R506_is_destination_of_Transition() );
        return transitionset;
    }
    @Override
    public NoEventTransitionSet R508_is_origination_of_NoEventTransition() throws XtumlException {
        NoEventTransitionSet noeventtransitionset = new NoEventTransitionSetImpl();
        for ( StateMachineState statemachinestate : this ) noeventtransitionset.addAll( statemachinestate.R508_is_origination_of_NoEventTransition() );
        return noeventtransitionset;
    }
    @Override
    public MooreActionHomeSet R511_MooreActionHome() throws XtumlException {
        MooreActionHomeSet mooreactionhomeset = new MooreActionHomeSetImpl();
        for ( StateMachineState statemachinestate : this ) mooreactionhomeset.add( statemachinestate.R511_MooreActionHome() );
        return mooreactionhomeset;
    }


    @Override
    public StateMachineState nullElement() {
        return StateMachineStateImpl.EMPTY_STATEMACHINESTATE;
    }

    @Override
    public StateMachineStateSet emptySet() {
      return new StateMachineStateSetImpl();
    }

    @Override
    public StateMachineStateSet value() {
        return this;
    }

    @Override
    public List<StateMachineState> elements() {
        StateMachineState[] elements = toArray(new StateMachineState[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/StateMachineStateSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.statemachine.StateSet;
import io.ciera.tool.sql.architecture.statemachine.impl.StateSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.I_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineState;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NoEventTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateEventMatrixEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class StateMachineStateSetImpl extends InstanceSet<StateMachineStateSet,StateMachineState> implements StateMachineStateSet {

    public StateMachineStateSetImpl() {
    }

    public StateMachineStateSetImpl(Comparator<? super StateMachineState> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setName( m_Name );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMstt_ID( UniqueId m_SMstt_ID ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setSMstt_ID( m_SMstt_ID );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setNumb( int m_Numb ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setNumb( m_Numb );
    }
    @Override
    public void setFinal( int m_Final ) throws XtumlException {
        for ( StateMachineState statemachinestate : this ) statemachinestate.setFinal( m_Final );
    }


    // selections
    @Override
    public I_INSSet R2915_defines_state_of_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( StateMachineState statemachinestate : this ) i_insset.addAll( statemachinestate.R2915_defines_state_of_I_INS() );
        return i_insset;
    }
    @Override
    public StateSet R4758_State() throws XtumlException {
        StateSet stateset = new StateSetImpl();
        for ( StateMachineState statemachinestate : this ) stateset.add( statemachinestate.R4758_State() );
        return stateset;
    }
    @Override
    public SM_SMSet R501_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( StateMachineState statemachinestate : this ) sm_smset.add( statemachinestate.R501_SM_SM() );
        return sm_smset;
    }
    @Override
    public StateEventMatrixEntrySet R503_receives_StateEventMatrixEntry() throws XtumlException {
        StateEventMatrixEntrySet stateeventmatrixentryset = new StateEventMatrixEntrySetImpl();
        for ( StateMachineState statemachinestate : this ) stateeventmatrixentryset.addAll( statemachinestate.R503_receives_StateEventMatrixEntry() );
        return stateeventmatrixentryset;
    }
    @Override
    public TransitionSet R506_is_destination_of_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( StateMachineState statemachinestate : this ) transitionset.addAll( statemachinestate.R506_is_destination_of_Transition() );
        return transitionset;
    }
    @Override
    public NoEventTransitionSet R508_is_origination_of_NoEventTransition() throws XtumlException {
        NoEventTransitionSet noeventtransitionset = new NoEventTransitionSetImpl();
        for ( StateMachineState statemachinestate : this ) noeventtransitionset.addAll( statemachinestate.R508_is_origination_of_NoEventTransition() );
        return noeventtransitionset;
    }
    @Override
    public MooreActionHomeSet R511_MooreActionHome() throws XtumlException {
        MooreActionHomeSet mooreactionhomeset = new MooreActionHomeSetImpl();
        for ( StateMachineState statemachinestate : this ) mooreactionhomeset.add( statemachinestate.R511_MooreActionHome() );
        return mooreactionhomeset;
    }


    @Override
    public StateMachineState nullElement() {
        return StateMachineStateImpl.EMPTY_STATEMACHINESTATE;
    }

    @Override
    public StateMachineStateSet emptySet() {
      return new StateMachineStateSetImpl();
    }

    @Override
    public StateMachineStateSet emptySet(Comparator<? super StateMachineState> comp) {
      return new StateMachineStateSetImpl(comp);
    }

    @Override
    public StateMachineStateSet value() {
        return this;
    }

    @Override
    public List<StateMachineState> elements() {
        StateMachineState[] elements = toArray(new StateMachineState[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
